from subprocess import call
from landslide.generator import Generator
import os
import time

def dirname():
    return os.path.dirname(os.path.realpath(__file__))

def file_in_dir(filename):
    return os.path.join(dirname(), filename)

def open_slides():
    cmd = "landslide -o out.html {0}".format(file_in_dir('slides.md'))
    slides_path = file_in_dir('slides.md')
    output_path = 'pipped-slides.html'
    Generator(slides_path, **{
        'embed': True,
        'relative': True,
        'destination_file': output_path
    }).execute()
    call(['open', output_path])

    # sleep to let the browser open
    time.sleep(1)

    call(['rm', output_path])

def run():
    open_slides()



from setuptools import setup

description = """
a pip package containing a presentation
on ho to publish pip packages
"""

setup(
    name='pipped',
    version='0.0.1',
    packages=['pipped'],
    description=description,
    url='https://github.com/brianc/publishing-pip-packages',
    author='Brian M. Carlson',
    author_email='brian.m.carlson@gmail.com',
    install_requires=['landslide==1.1.1'],
    data_files=[('slides', ['data/SLIDES.md'])],
    entry_points={
        'console_scripts': [
            'pipped = pipped.cli:run'
        ]
    }
)
